@@ -21,9 +21,6 @@ global test_value
 test_value = 0
 global var_dict
 var_dict = {}
-global pl1
-global st1
-global al_pl_1
 global addition_list
 addition_list = []
 global howmany
@@ -52,26 +49,34 @@ class random:
         pass
 def define_auto(code):
     var_name = code.split("=")[0]
+    global var_dict_type
     global var_list
     global var_dict
     global javacode
+    m = ''
     if not var_list.__contains__(var_name):
         data = code.split("=")[1]
-        code = data.split(".")[-1]
+        code1 = code.split(".")[-1]
+        if code1.__contains__("size"):
+            code1 = code.split(".")[-2]
+        elif code1.__contains__("get("):
+            code1 = code
+        code = code1
         type_Var = ""
         m = ''
+        code = code.replace(" ","")
         if code.__contains__('getPlayer') or code.__contains__('sender'):
             type_Var = "Player"
-            m = 'public Player '+var_name+";\n"
+            m = 'public Player '+var_name+"= new Player();\n"
         elif code.__contains__('getWorld'):
             type_Var = "World"
             m = 'public World '+var_name+";\n"
         elif code.__contains__('getItemInHand'):
             type_Var = "ItemStack"
-            m = 'public ItemStack '+var_name+";\n"
+            m = 'public ItemStack '+var_name+" = new ItemStack();\n"
         elif code.__contains__('getName') or code.__contains__('toString'):
             type_Var = "String"
-            m = 'public String '+var_name+";\n"
+            m = 'public String '+var_name+"= new String();\n"
         elif code.__contains__('getInventory'):
             type_Var = "Inventory"
             m = 'public Inventory '+var_name+";\n"
@@ -83,24 +88,22 @@ def define_auto(code):
             type_Var = "Integar"
         elif code.__contains__('getBlock'):
             type_Var = "Block"
-            m = 'public Block '+var_name+";\n"
+            m = 'public Block '+var_name+" = new Block();;\n"
         elif code.__contains__('getMaterial'):
-            m = 'public Material '+var_name+";\n"
+            m = 'public Material '+var_name+" = new Material();\n"
             type_Var = "Material"
         elif code.__contains__(".get("):
             code = code.replace(".get("," ")
-            code = code.replace(")","")
+            code = code.replace(")"," ")
             code = code.replace("="," ")
             code1 = code.split(" ")[0]
             code2 = code.split(" ")[1]
-            code3 = code.split(" ")[2]
-            m = 'public '+var_dict.get(code2)+' '+code1+";\n"
+            var_name = code1
+            m = 'public '+str(var_dict.get(code2))+' '+code1+";\n"
             type_Var = var_dict.get(code2)
-        if not var_dict.__contains__(var_name):
-            var_dict[var_name] = (type_Var)
+        var_dict[var_name] = (type_Var)
         var_dict_type[type_Var] = True
-        javacode = javacode.replace("public class Main extends JavaPlugin implements Listener{\n",
-        "public class Main extends JavaPlugin implements Listener{\n"+'   '+m)
+        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'   '+m)
         var_list.append(var_name)
     return javacode
 class space:
@@ -109,22 +112,48 @@ class space:
         global javacode
         global java_space
         global howmany
-        global check_list    
+        global check_list
         while not code.__contains__("   "*python_space):
-            
-            java_space -= 1
+            java_space -=1
             javacode = space.getspace(javacode)
             javacode += "}\n"
-            python_space -= 1
+            python_space -=1
         return code
     def getspace(string):
         global java_space
         string += "   "*java_space
         return string
 def init():
-    file = open("data/src/main/resources/plugin.yml","w")
-    file.write("name: minepy\nmain: Main.Main\nversion: 1.0\napi-version: 1.16\ncommands:\n")
-    file.close()
+    global playermoveevent1
+    global blockbreakevent1
+    global playerinteractevent1
+    global playerjoinevent1
+    global playeritemheldevent1
+    global blockfertilizeevent1
+    global blockexplodeevent1
+    global blockcookevent1
+    global blockdropitemevent1
+    global blockredstoneevent1
+    global entitydeathevent1
+    global entitydropitemevent1
+    global entitypickupitemevent1
+    global playerdeathevent1
+    global projectilehitevent1
+    playerjoinevent1 = playerjoinevent()
+    playermoveevent1 = playermoveevent()
+    blockbreakevent1 = blockbreakevent()
+    playerinteractevent1 = playerinteractevent()
+    playeritemheldevent1 = playeritemheldevent()
+    blockfertilizeevent1 = blockfertilizeevent()
+    blockexplodeevent1 = blockexplodeevent()
+    blockcookevent1 = blockcookevent()
+    blockdropitemevent1 = blockdropitemevent()
+    blockredstoneevent1 = blockredstoneevent()
+    entitydeathevent1 = entitydeathevent()
+    entitydropitemevent1 = entitydropitemevent()
+    entitypickupitemevent1 = entitypickupitemevent()
+    playerdeathevent1 = playerdeathevent()
+    projectilehitevent1 = projectilehitevent()
     global bc1
     bc1 = Block()
     global ac1
@@ -145,8 +174,14 @@ def init():
     pl1 = Player()
     global lc1
     lc1 = Location()
+    file = open("data/src/main/resources/plugin.yml","w")
+    file.write("name: minepy\nmain: Main.Main\nversion: 1.0\napi-version: 1.16\n")
+    file.close()
     global check_list
     check_list.append('init')
+def dojava(code):
+    global check_list
+    check_list.append('java')
 def print(message):
     check_list.append('sys_activity')
 class Player:
@@ -195,6 +230,8 @@ class ArrayList:
         if not addition_list.__contains__('java.util.ArrayList'):
             addition_list.append('java.util.ArrayList')
         global check_list
+        global var_dict_type
+        var_dict_type['ArrayList'] = True
         check_list.append("define")
         self.type = typeof
     def add(self,something):
@@ -204,19 +241,69 @@ class ArrayList:
         global pl1
         if self.type == "player":
             return pl1
+    def size(self):
+        pass
+    def __contains__(self,something):
+        import inspect
+        frame = inspect.stack()[1]
+        module = inspect.getmodule(frame[0])
+        filename = module.__file__
+        if self.type != type(something):
+            raise Exception('compare thing type have to be same as type of list '+filename+'", line '+str(long)+',')
 class String:
     def __init__(self):
         global check_list
         check_list.append("define")
-class Event:
-    def __init__(self,eventname):
-        global check_list
-        check_list.append("define_python")
-    def getPlayer(self):
-        return pl1
-    def setCancelled(self,status):
-        global check_list
-        check_list.append("activity")
+def Event():
+    global check_list_var
+    check_list.append("define_python")
+    global event_name
+    global playermoveevent1
+    global blockbreakevent1
+    global playerinteractevent1
+    global playerjoinevent1
+    global playeritemheldevent1
+    global blockfertilizeevent1
+    global blockexplodeevent1
+    global blockcookevent1
+    global blockdropitemevent1
+    global blockredstoneevent1
+    global entitydeathevent1
+    global entitydropitemevent1
+    global entitypickupitemevent1
+    global playerdeathevent1
+    global projectilehitevent1
+    event_name = event_name.lower()
+    if event_name == "playermoveevent":
+        return playermoveevent1
+    elif event_name == "blockbreakevent":
+        return blockbreakevent1
+    elif event_name == "playerinteractevent":
+        return playerinteractevent1
+    elif event_name == "playerjoinevent":
+        return playerjoinevent1
+    elif event_name == "playeritemheldevent":
+        return playeritemheldevent1
+    elif event_name == "blockfertilizeevent":
+        return blockfertilizeevent1
+    elif event_name == "blockexplodeevent":
+        return blockexplodeevent1
+    elif event_name == "blockcookevent":
+        return blockcookevent1
+    elif event_name == "blockdropItemevent":
+        return blockdropitemevent1
+    elif event_name == "blockredstoneevent":
+        return blockredstoneevent1
+    elif event_name == "entitydeathevent":
+        return entitydeathevent1
+    elif event_name == "entitydropItemevent":
+        return entitydropitemevent1
+    elif event_name == "entitypickupitemevent":
+        return entitypickupitemevent1
+    elif event_name == "playerdeathevent":
+        return playerdeathevent1
+    elif event_name == "projectilehitevent":
+        return projectilehitevent1
 class Location:
     def __init__(self):
         global addition_list
@@ -248,6 +335,9 @@ class Location:
         global type_list
         type_list.append("int")
         return 1
+    def getWorld(self):
+        global wr1
+        return wr1
 class Random:
     def __init__(self):
         global addition_list
@@ -255,8 +345,8 @@ class Random:
         global check_list
         check_list.append("define")
     def nextInt(self,value):
-        return 15
-class Bukkit:
+        return 1
+class Minecraft:
     def getPlayers():
         global pl1
         global Playerinclude
@@ -265,6 +355,9 @@ class Bukkit:
     def getWorlds():
         global wr1
         return wr1
+    def MaterialList():
+        global mt1
+        return mt1
 class Inventory:
     def __init__(self):
         global check_list
@@ -283,15 +376,11 @@ class ItemStack:
         global check_list
         check_list.append("define")
     def setMaterial(self,something):
-        global is1
         global check_list
         check_list.append("activity")
-        return is1
     def setAmount(self,amount):
-        global is1
         global check_list
         check_list.append("activity")
-        return is1
     def getMaterial(self):
         global is1
         return is1
@@ -314,6 +403,9 @@ class World:
             addition_list.append('org.bukkit.GameRule')
         global check_list    
         check_list.append("activity")
+    def dropItem(self,location,itemstack):
+        global check_list    
+        check_list.append("activity")
 class Block:
     def __init__(self):
         self.type = "Block"
@@ -327,8 +419,8 @@ class Block:
         return mt1
 def time(when):
     global n
-    n += 1
-    if n == 1:
+    n +=1
+    if n ==1:
         global check_list
         check_list.append("while_time")
         return True
@@ -336,9 +428,11 @@ def time(when):
         n = 0
         return False
 def event(when):
+    global event_name
+    event_name = when
     global n
-    n += 1
-    if n == 1:
+    n +=1
+    if n ==1:
         global check_list
         check_list.append("while_event")
         return True
@@ -347,8 +441,8 @@ def event(when):
         return False
 def when(*test):
     global k
-    k += 1
-    if k == 1:
+    k +=1
+    if k ==1:
         global check_list
         check_list.append("if")
         return True
@@ -356,11 +450,11 @@ def when(*test):
         k = 0
         return False
 def repeat(*var_name):
-    if len(var_name) == 1:
+    if len(var_name) ==1:
         list_name = var_name[0]
         global pl1
         global wr1
-    
+        global mt1
         check_list.append("for")
         g = []
         global list_name_list
@@ -371,10 +465,16 @@ def repeat(*var_name):
         elif list_name.type == "world":
             g.append(wr1)
             return g
+        elif list_name.type == "material":
+            g.append(mt1)
+            return g
+        elif list_name == "Minecraft.MaterialList()":
+            g.append(mt1)
+            return g
 def command(some):
     global n
-    n += 1
-    if n == 1:
+    n +=1
+    if n ==1:
         global check_list
         check_list.append("command")
         return True
@@ -405,7 +505,6 @@ def make():
     sys.stdout.write("']")
     sys.stdout.write("\n")
     javacode = ''
-    import inspect
     frame = inspect.stack()[1]
     module = inspect.getmodule(frame[0])
     filename = module.__file__
@@ -413,38 +512,37 @@ def make():
     lines = file.readlines()
     global long
     for code in lines:
+        
         code = str(code)
         code = code.replace("when=", "")
         getvalue = distinguish_execution(code)
         if getvalue == True:
             m = check_list[check_list_var]
-            if len(check_list) > 1:
-                if not check_list[1] == 'make':
-                    code = space.forfinish(code)
-            if m != 'make' and howmany == 1:
+            code = space.forfinish(code)
+            if m != 'make' and howmany ==1:
                 howmany = 0
                 code = space.forfinish(code)
-                howmany = 1
+                howmany =1
             code = code.replace("   ","")
             code = code.replace("\n","")
             if m == 'init':
                 del check_list[0] 
                 javacode = space.getspace(javacode)
                 javacode += 'public class Main extends JavaPlugin implements Listener{\n'
-                java_space += 1
+                java_space +=1
                 addition_list.append('org.bukkit.plugin.java.JavaPlugin')
                 addition_list.append('org.bukkit.event.Listener')
             elif code.__contains__(".")  and code.__contains__("=") and not(code.__contains__("while")) and not(code.__contains__("for")):
                 if not (code.__contains__("randint")):
-                    if not code[len(code)-2:len(code)] == "()":
-                        # raise ValueError("you have to set () in '"+code+"'\n")
-                        global long
-                        raise Exception('you should put () in "'+filename+'", line '+str(long)+',')
+                    if not (code.__contains__("get(")):
+                        if not code[len(code)-2:len(code)] == "()":
+                            # raise ValueError("you have to set () in '"+code+"'\n")
+                            global long
+                            raise Exception('you should put () in "'+filename+'", line '+str(long)+',')
                 else:
                     if not var_list.__contains__("random"):
-                        sg = "Random random;\n"
-                        javacode = javacode.replace("public class Main extends JavaPlugin implements Listener{\n",
-                        "public class Main extends JavaPlugin implements Listener{\n"+"   "+sg)
+                        m = "public Random random = new Random();\n"
+                        javacode = javacode.replace("implements Listener{\n","implements Listener{\n"+'   '+m)
                         var_list.append("random")
                         addition_list.append("java.util.Random")
                     var = code.split("=")[0]
@@ -453,10 +551,9 @@ def make():
                     code2 = code1.split(",")[0]
                     code3 = code1.split(",")[1]
                     code3 = code3.split(")")[0]
-                    code = var+"="+"random.randint("+code3+")"+"+"+code2
-                javacode = space.getspace(javacode)
-                code = code.replace(" ","")
+                    code = var+"="+"random.randint("+code3+")"
                 javacode = define_auto(code)
+                code = code.replace(" ","")
                 code = code.replace("randint","nextInt")
                 code = code.replace("="," = ")
                 if code.__contains__("getItemInHand"):
@@ -464,7 +561,12 @@ def make():
                         javacode = javacode.replace('public boolean','@SuppressWarnings("deprecation")\n'+'   '+'public boolean')
                 code = code.replace("Command.sender()", "(Player) sender")
                 code = code.replace("Command.","")
-                code = code.replace("label()", "Label")
+                code = code.replace("()","")
+                code = code.replace("getPlayer","getPlayer()")
+                code = code.replace("getWorld","getWorld()")
+                code = code.replace("getLocation","getLocation()")
+                code = code.replace("getInventory","getInventory()")
+                code = code.replace("size","size()")
                 code = code.replace("Material","Type")
                 if code.__contains__("getX") or code.__contains__("getY") or code.__contains__("getZ"):
                     i1 = code.split("=")[0]
@@ -472,6 +574,7 @@ def make():
                     m = type_list[0]
                     del type_list[0]
                     code = i1+'= ('+str(m) +')'+ i2
+                javacode = space.getspace(javacode)
                 javacode += code +';\n'
             elif not code.__contains__("("):
                 code = code.replace(" ","")
@@ -479,7 +582,6 @@ def make():
                 if not var_list.__contains__(var_name):
                     data = code.split("=")[1]
                     if data.__contains__('"'):
-                        javacode = space.getspace(javacode)
                         javacode += 'String '+var_name+";\n"
                     else:
                         javacode = space.getspace(javacode)
@@ -503,9 +605,11 @@ def make():
                     javacode += 'public void onEnable(){\n'
                 if code1 == "Disable":
                     javacode += 'public void onDisable(){\n'
-                python_space += 1
-                java_space += 1
+                python_space =1
+                java_space = 2
             elif m == 'while_event':
+                java_space =1
+                python_space = 0
                 global Event_name
                 Event_name = ''
                 del check_list[0] 
@@ -515,7 +619,7 @@ def make():
                     r = 2*"   "
                     javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'Bukkit.getPluginManager().registerEvents(this,this);\n')
                 global test_value
-                test_value += 1
+                test_value +=1
                 name = 'test'+str(test_value)
                 javacode += "   "*java_space
                 javacode += "@EventHandler\n"
@@ -537,8 +641,8 @@ def make():
                     addition_list.append('org.bukkit.event.entity.'+code1)
                 javacode = space.getspace(javacode)
                 javacode += 'public void '+name+'('+code1+' e'+') {\n'
-                python_space += 1
-                java_space += 1
+                python_space +=1
+                java_space +=1
                 Event_name = code1
             elif m == 'define_python':
                 del check_list[0] 
@@ -559,6 +663,8 @@ def make():
                     var_dict[variable_name] = species
                 elif middle_part == "Random":
                     m = 'Random '+variable_name+' = new Random();\n'
+                elif middle_part == "ItemStack":
+                    m = 'ItemStack '+variable_name+' = new ItemStack(Material.AIR,1);\n'
                 else:
                     if middle_part == "Player":
                         Playerinclude = True
@@ -575,6 +681,7 @@ def make():
                 code = code.replace("Material","Type")
                 code = code.replace("()","")
                 code = code.replace("True","true")
+                code = code.replace("False","false")
                 if code.__contains__("setCancel") and Event_name == "PlayerJoinEvent":
                     raise Exception('PlayerJoinEvent cannot put setCancel "'+filename+'", line '+str(long)+',')
                 javacode += code +';\n'
@@ -620,12 +727,18 @@ def make():
                 del check_list[0] 
                 if code.__contains__("print"):
                     code = code.replace(" ","")
-                    code += ');\n'
                     javacode = space.getspace(javacode)
                     code = code.replace("print(","")
-                    code = code.replace(");",";")
-                    code = code.replace(")",'+"")')
-                    javacode += 'System.out.println('+code
+                    code = code.replace('")','"+"")')
+                    javacode += 'System.out.println('+code+';\n'
+            elif m == "java":
+                del check_list[0]
+                code = code.replace(')',"")
+                code = code.replace('dojava(',"")
+                code = code.replace('"','')
+                code = code.lstrip()
+                javacode = space.getspace(javacode)
+                javacode += code+';\n'
             elif m == "setnum":
                 del check_list[0] 
                 javacode = space.getspace(javacode)
@@ -657,6 +770,8 @@ def make():
                 del check_list[0] 
                 code = code.replace(" ","")
                 javacode = space.getspace(javacode)
+                code = code.replace("Minecraft.MaterialList()","Material.values()")
+                code = code.replace("Minecraft","Bukkit")
                 code = code.replace("for","")
                 code = code.replace("t(","t")
                 code = code.replace("):","")
@@ -672,8 +787,8 @@ def make():
                 type_var = k.upper() + type_var[1:len(type_var)]
                 javacode += "for ("+type_var+" "+i1+":"+i2+"){\n"
                 del list_name_list[0]
-                python_space += 1
-                java_space += 1
+                python_space +=1
+                java_space +=1
                 var_dict_type[type_var] = True
             elif m == 'for_range':
                 del check_list[0] 
@@ -689,8 +804,8 @@ def make():
                     javacode += 'Integer '+var_name +';\n'
                     javacode = space.getspace(javacode)
                 javacode += 'for('+var_name+' = '+str(int(start_1)-1)+'; '+var_name+' < '+end+'; '+ var_name+"++ ) {\n"
-                python_space += 1
-                java_space += 1
+                python_space +=1
+                java_space +=1
             elif m == 'if':
                 del check_list[0] 
                 code = code.replace(" ","")
@@ -700,6 +815,7 @@ def make():
                 code = code.replace("==",".equals(")
                 code = code.replace(":",") {")
                 code =  code.replace("()","")
+                code = code.replace(")))","))")
                 code1 = code.split(" ")[0]
                 if code.__contains__("and"):
                     code2 = code.split("and")
@@ -717,48 +833,55 @@ def make():
                 code = code.replace("or"," || ")
                 javacode = space.getspace(javacode)
                 javacode += code+'\n'
-                java_space += 1
-                python_space += 1
+                java_space +=1
+                python_space +=1
             elif m == 'command':
                 del check_list[0]
                 code = space.forfinish(code)
                 global comnum
                 code = code.replace(" ","")
-                code = code.replace('whilecommand("',"")
-                code = code.replace('"):',"")
+                code = code.replace('whilecommand(',"")
+                code = code.replace('):',"")
+                code = code.replace('"',"")
+                code = code.replace("'","")
+                sys.stdout.write(code)
                 name = 'onCommand'
-                comnum += 1
-                java_space = 1
+                comnum +=1
+                java_space =1
                 python_space = 0
                 if not javacode.__contains__('public boolean '+name+'(CommandSender sender, Command cmd, String Label, String[] args) {\n'):
                     javacode += '   '
                     javacode += 'public boolean '+name+'(CommandSender sender, Command cmd, String Label, String[] args) {\n'
-                java_space += 1
-                python_space += 1
+                java_space +=1
+                python_space +=1
                 javacode += '   '*2+'if (Label.equalsIgnoreCase("'+code+'")) {\n'
-                java_space += 1
-                howmany = 1
+                java_space +=1
+                howmany =1
                 if not addition_list.__contains__("org.bukkit.command.Command"): 
                     addition_list.append("org.bukkit.command.Command")
                     addition_list.append("org.bukkit.command.CommandSender")
                 r = 2*"   "
                 # javacode = javacode.replace('public void onEnable(){\n', 'public void onEnable(){\n'+r+'this.getCommand("'+code+'").setExecutor(this);\n')
+                file1 = open("data/src/main/resources/plugin.yml","r")
                 file = open("data/src/main/resources/plugin.yml","a")
+                if not file1.readlines().__contains__("commands:\n"):
+                    file1.close()
+                    file.write('commands:\n')
                 file.write('  '+code+':\n')
                 file.close()
             elif m == "make":
                 del check_list[0]
-                if howmany == 1:
+                if howmany ==1:
                     while java_space > 0:
                         if java_space == 2:
                             javacode = space.getspace(javacode)
                             javacode += "return false;\n"
-                        java_space -= 1
+                        java_space -=1
                         javacode = space.getspace(javacode)
                         javacode += "}\n"
                 else:
                     while java_space > 0:
-                        java_space -= 1
+                        java_space -=1
                         javacode = space.getspace(javacode)
                         javacode += "}\n"
     if var_dict_type.get("Location") == False:
@@ -788,7 +911,7 @@ def make():
 def distinguish_execution(code):
     code = str(code)
     global long
-    long += 1
+    long +=1
     if not code.__contains__("import"):
         no_blank_i = code.replace(" ","")
         if not no_blank_i[0] == "#":
@@ -876,38 +999,6 @@ class Action:
             addition_list.append('org.bukkit.event.block.Action')
         global check_list    
         check_list.append("define")
-def PlayerMoveEvent(*details):
-    return "PlayerMoveEvent"
-def BlockBreakEvent():
-    return "BlockBreakEvent"
-def PlayerInteractEvent():
-    return "PlayerInteractEvent"
-def PlayerJoinEvent():
-    return "PlayerJoinEvent"
-def PlayerItemHeldEvent():
-    return "PlayerItemHeldEvent"
-def BlockFertilizeEvent():
-    return "BlockFertilizeEvent"
-def BlockExplodeEvent():
-    return "BlockExplodeEvent"
-def BlockCookEvent():
-    return "PlayerInteractEvent"
-def BlockDropItemEvent():
-    return "BlockDropItemEvent"
-def BlockRedstoneEvent():
-    return "BlockRedstoneEvent"
-def EntityDeathEvent():
-    return "EntityDeathEvent"
-def EntityDropItemEvent():
-    return "EntityDropItemEvent"
-def EntityPickupItemEvent():
-    return "EntityPickupItemEvent"
-def EntityTeleportEvent():
-    return "EntityTeleportEvent"
-def PlayerDeathEvent():
-    return "PlayerDeathEvent"
-def ProjectileHitEvent():
-    return "ProjectileHitEvent"
 def player():
     return "player"
 def world():
@@ -916,13 +1007,16 @@ def Enable():
     return "Enable"
 def Disable():
     return "Disable"
+def material():
+    return "material"
 class Material:
     def __init__(self):
         self.type = "Material"
         global addition_list
         if not addition_list.__contains__('org.bukkit.Material'):
             addition_list.append('org.bukkit.Material')
-        global check_list    
+        global check_list
+        self.type = "material"    
         check_list.append("define")
     def toString(self):
         return "hello"
@@ -2002,4 +2096,170 @@ class Material:
     def POTTED_CRIMSON_FUNGUS(): return mt1
     def POTTED_WARPED_FUNGUS(): return mt1
     def POTTED_CRIMSON_ROOTS(): return mt1
-    def POTTED_WARPED_ROOTS(): return mt1
\ No newline at end of file
+    def POTTED_WARPED_ROOTS(): return mt1
+class playermoveevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def getPlayer(self):
+        global pl1
+        return pl1
+    def getFrom(self):
+        global lc1
+        return lc1
+    def getTo(self):
+        global lc1
+        return lc1
+    def setCancelled(self,status):
+        global check_list
+        check_list.append("activity")
+class blockbreakevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def getPlayer(self):
+        global pl1
+        return pl1
+    def setCancelled(self,status):
+        global check_list
+        check_list.append("activity")
+    def getBlock(self):
+        global bc1
+        return bc1
+    def setDropItems(self,bool):
+        global check_list
+        check_list.append("activity")
+class playerinteractevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def getAction(self):
+        pass
+    def getClickedBlock(self):
+        global bc1
+        return bc1
+    def setCancelled(self,status):
+        global check_list
+        check_list.append("activity")
+    def getItem(self):
+        global ic1
+        return ic1
+    def getMaterial(self):
+        global mt1
+        return mt1
+class playerjoinevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def setJoinMessage(self,message):
+        global check_list
+        check_list.append("activity")
+class playeritemheldevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class blockfertilizeevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def setCancelled(self,status):
+        global check_list
+        check_list.append("activity")
+class blockexplodeevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class blockcookevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class blockdropitemevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class blockredstoneevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class entitydeathevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class entitydropitemevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class entitypickupitemevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+class playerdeathevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+    def getEventName(self):
+        return "hello"
+    def getEntity(self):
+        global pl1
+        return pl1
+    def setDeathMessage(self,something):
+        global check_list
+        check_list.append("activity")
+class projectilehitevent:
+    def getEventName(self):
+        return "hello"
+    def __init__(self):
+        pass
+def PlayerMoveEvent():
+    return "PlayerMoveEvent"
+def BlockBreakEvent():
+    return "BlockBreakEvent"
+def PlayerInteractEvent():
+    return "PlayerInteractEvent"
+def PlayerJoinEvent():
+    return "PlayerJoinEvent"
+def PlayerItemHeldEvent():
+    return "PlayerItemHeldEvent"
+def BlockFertilizeEvent():
+    return "BlockFertilizeEvent"
+def BlockExplodeEvent():
+    return "BlockExplodeEvent"
+def BlockCookEvent():
+    return "PlayerInteractEvent"
+def BlockDropItemEvent():
+    return "BlockDropItemEvent"
+def BlockRedstoneEvent():
+    return "BlockRedstoneEvent"
+def EntityDeathEvent():
+    return "EntityDeathEvent"
+def EntityDropItemEvent():
+    return "EntityDropItemEvent"
+def EntityPickupItemEvent():
+    return "EntityPickupItemEvent"
+def EntityTeleportEvent():
+    return "EntityTeleportEvent"
+def PlayerDeathEvent():
+    return "PlayerDeathEvent"
+def ProjectileHitEvent():
+    return "ProjectileHitEvent"
+# m = ""
+# file = open("hello.txt","r")
+# for i in file.readlines():
+#     i = i.lower()
+#     m += i
+# file = open("hello.txt","w")
+# file.write(m)
\ No newline at end of file
